@@ -26,6 +26,9 @@ INVALIDPARAMETER_AUTHINFO = 'InvalidParameter.AuthInfo'
 # Invalid `CacheInfo` value
 INVALIDPARAMETER_CACHEINFO = 'InvalidParameter.CacheInfo'
 
+# Invalid CDN playback domain name.
+INVALIDPARAMETER_CDNDOMAIN = 'InvalidParameter.CdnDomain'
+
 # Invalid `ChannelId`.
 INVALIDPARAMETER_CHANNELID = 'InvalidParameter.ChannelId'
 
